==> open_watcom_1.4.0-src.zip: bld/ndisasm/stand/h/init.h <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#ifndef WDIS_INIT_INCLUDED
#define WDIS_INIT_INCLUDED

#include "global.h"

extern void                     PrintErrorMsg( return_val, int );
extern void                     Init( void );
extern void                     CloseObjFile( void );
extern orl_machine_type         GetMachineType();
extern orl_file_format          GetFormat();
extern int                      IsIntelx86();
extern void                     LeaveProgram( return_val, int );
extern unsigned_16              FileU16toHostU16(unsigned_16);
extern unsigned_32              FileU32toHostU32(unsigned_32);
extern unsigned_64              FileU64toHostU64(unsigned_64);

#endif

==> open_watcom_1.7.0-src.zip: bld/ndisasm/stand/h/init.h <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#ifndef WDIS_INIT_INCLUDED
#define WDIS_INIT_INCLUDED

#include "global.h"

extern void                     PrintErrorMsg( return_val, int );
extern void                     Init( void );
extern void                     CloseObjFile( void );
extern orl_machine_type         GetMachineType( void );
extern orl_file_format          GetFormat( void );
extern int                      IsIntelx86( void );
extern void                     LeaveProgram( return_val, int );
extern unsigned_16              FileU16toHostU16(unsigned_16);
extern unsigned_32              FileU32toHostU32(unsigned_32);
extern unsigned_64              FileU64toHostU64(unsigned_64);

#endif
